@@ -192,10 +192,7 @@ def loadclass(module_and_name, classes=None):
             __import__(module)
             obj = sys.modules[module]
             for class_name in names[up_to:]:
-                try:
-                    obj = getattr(obj, class_name)
-                except AttributeError:
-                    continue
+                obj = getattr(obj, class_name)
             return obj
         except (AttributeError, ImportError, ValueError):
             continue
@@ -327,7 +324,7 @@ class Unpickler(object):
 
     def _swap_proxies(self):
         """Replace proxies with their corresponding instances"""
-        for (obj, attr, proxy, method) in self._proxies:
+        for obj, attr, proxy, method in self._proxies:
             method(obj, attr, proxy)
         self._proxies = []
 
@@ -628,6 +625,15 @@ class Unpickler(object):
                         # issue #240
                         # i think this is the only way to set frozen dataclass attrs
                         object.__setattr__(instance, k, value)
+                    except AttributeError as e:
+                        # some objects may raise this for read-only attributes (#422)
+                        if (
+                            hasattr(instance, "__slots__")
+                            and not len(instance.__slots__)
+                            and issubclass(instance.__class__, int)
+                        ):
+                            continue
+                        raise e
                 else:
                     setattr(instance, f"_{instance.__class__.__name__}{k}", value)
 
@@ -763,6 +769,7 @@ class Unpickler(object):
             return instance
 
         if cls is None:
+            self._process_missing(class_name)
             return self._mkref(obj)
 
         return self._restore_object_instance(obj, cls, class_name)
@@ -826,7 +833,7 @@ class Unpickler(object):
 
     def _restore_tags(self, obj):
         try:
-            if not tags.RESERVED <= set(obj) and not type(obj) in (list, dict):
+            if not tags.RESERVED <= set(obj) and type(obj) not in (list, dict):
 
                 def restore(x):
                     return x
