@@ -7,6 +7,7 @@
 # you should have received as part of this distribution.
 
 import datetime
+import sys
 import time
 import unittest
 
@@ -167,6 +168,25 @@ class DateTimeSimpleTestCase(unittest.TestCase):
         test_obj_decoded = jsonpickle.decode(json)
         self.assertEqual(test_obj_decoded.data['ts'], test_obj_decoded.data_ref['ts'])
 
+    @unittest.skipIf(sys.version_info < (3, 9), "only tested for python >= 3.9")
+    def test_datetime_with_ZoneInfo(self):
+        """
+        jsonpickle should pickle a datetime object with time zone info
+        """
+        # if sys.version_info >= (3, 9):
+        from zoneinfo import ZoneInfo
+
+        now = datetime.datetime.now()
+
+        SaoPaulo = ZoneInfo('America/Sao_Paulo')
+        USEastern = ZoneInfo('US/Eastern')
+
+        now_sp = now.replace(tzinfo=SaoPaulo)
+        now_us = now.replace(tzinfo=USEastern)
+
+        self._roundtrip(now_sp)
+        self._roundtrip(now_us)
+
 
 class DateTimeAdvancedTestCase(unittest.TestCase):
     def setUp(self):
