@@ -9,7 +9,6 @@ import re
 import threading
 
 import pytest
-import pytz
 from helper import SkippableTest
 
 import jsonpickle
@@ -123,7 +122,6 @@ class ThingWithQueue(object):
 
 
 class ThingWithSlots(object):
-
     __slots__ = ('a', 'b')
 
     def __init__(self, a, b):
@@ -132,7 +130,6 @@ class ThingWithSlots(object):
 
 
 class ThingWithInheritedSlots(ThingWithSlots):
-
     __slots__ = ('c',)
 
     def __init__(self, a, b, c):
@@ -141,7 +138,6 @@ class ThingWithInheritedSlots(ThingWithSlots):
 
 
 class ThingWithIterableSlots(object):
-
     __slots__ = iter('ab')
 
     def __init__(self, a, b):
@@ -176,6 +172,25 @@ class ThingWithClassAsDefaultFactory(collections.defaultdict):
         return self.__class__()
 
 
+class ThingWithDefaultFactoryRegistry:
+    """Counts calls to ThingWithDefaultFactory.__init__()"""
+
+    count = 0  # Incremented by ThingWithDefaultFactory().
+
+
+class ThingWithDefaultFactory:
+    """Class that ensures that provides a default factory"""
+
+    def __new__(cls, *args, **kwargs):
+        """Ensure that jsonpickle uses our constructor during initialization"""
+        return super().__new__(cls, *args, **kwargs)
+
+    def __init__(self):
+        self.default_factory = self.__class__
+        # Keep track of how many times this constructor has been run.
+        ThingWithDefaultFactoryRegistry.count += 1
+
+
 class IntEnumTest(enum.IntEnum):
     X = 1
     Y = 2
@@ -619,6 +634,19 @@ def test_defaultdict_roundtrip():
     assert newdefdict.default_factory == list
 
 
+def test_default_factory_initialization():
+    """Ensure that ThingWithDefaultFactory()'s constructor is called"""
+    thing = ThingWithDefaultFactory()
+    assert ThingWithDefaultFactoryRegistry.count == 1
+
+    thing.is_awesome = True
+    encoded = jsonpickle.encode(thing)
+    new_thing = jsonpickle.decode(encoded)
+
+    assert ThingWithDefaultFactoryRegistry.count == 2
+    assert new_thing.is_awesome
+
+
 def test_defaultdict_roundtrip_simple_lambda():
     """Make sure we can handle defaultdict(lambda: defaultdict(int))"""
     # setup a sparse collections.defaultdict with simple lambdas
@@ -1104,8 +1132,9 @@ def test_unicode_mixin():
 
 def test_datetime_with_tz_copies_refs():
     """Ensure that we create copies of referenced objects"""
-    d0 = datetime.datetime(2020, 5, 5, 5, 5, 5, 5, tzinfo=pytz.UTC)
-    d1 = datetime.datetime(2020, 5, 5, 5, 5, 5, 5, tzinfo=pytz.UTC)
+    utc = datetime.timezone.utc
+    d0 = datetime.datetime(2020, 5, 5, 5, 5, 5, 5, tzinfo=utc)
+    d1 = datetime.datetime(2020, 5, 5, 5, 5, 5, 5, tzinfo=utc)
     obj = [d0, d1]
     encoded = jsonpickle.encode(obj, make_refs=False)
     decoded = jsonpickle.decode(encoded)
